@@ -1,7 +1,9 @@
 package Sah::Schemas::Int;
 
-our $DATE = '2020-05-21'; # DATE
-our $VERSION = '0.075'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-07-16'; # DATE
+our $DIST = 'Sah-Schemas-Int'; # DIST
+our $VERSION = '0.076'; # VERSION
 
 1;
 # ABSTRACT: Sah schemas for various integers
@@ -18,7 +20,13 @@ Sah::Schemas::Int - Sah schemas for various integers
 
 =head1 VERSION
 
-This document describes version 0.075 of Sah::Schemas::Int (from Perl distribution Sah-Schemas-Int), released on 2020-05-21.
+This document describes version 0.076 of Sah::Schemas::Int (from Perl distribution Sah-Schemas-Int), released on 2021-07-16.
+
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <sharyanto@cpan.org>
 
 =head1 SAH SCHEMAS
 
@@ -149,6 +157,10 @@ feature.
 
 =head1 SEE ALSO
 
+L<Sah::Schemas::IntRange>
+
+L<Sah::PSchemas::IntRange>
+
 L<Sah> - specification
 
 L<Data::Sah>
@@ -159,7 +171,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018, 2017, 2016, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018, 2017, 2016, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
